.. module:: anhima.loc
.. moduleauthor:: Alistair Miles <alimanfoo@googlemail.com>

Locating samples, variants and genome positions
===============================================

Utility functions for extracting data on samples, variants and genome
positions.

See also the examples at:

- http://nbviewer.ipython.org/github/alimanfoo/anhima/blob/master/examples/loc.ipynb

.. autofunction:: take_sample
.. autofunction:: take_samples
.. autofunction:: query_variants
.. autofunction:: compress_variants
.. autofunction:: take_variants
.. autofunction:: locate_region
.. autofunction:: take_region
.. autofunction:: plot_variant_locator
.. autofunction:: windowed_variant_counts
.. autofunction:: plot_windowed_variant_counts
.. autofunction:: windowed_variant_density
.. autofunction:: plot_windowed_variant_density
.. autofunction:: windowed_statistic



